@@ -12,7 +12,7 @@ our @EXPORT_OK = qw/
     enclose_all
 /;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 my %MAP;
 {
@@ -136,7 +136,7 @@ Acme::EnclosedChar - Ⓔⓝⓒⓛⓞⓢⓔⓓ Ⓐⓛⓟⓗⓐⓝⓤⓜⓔⓡⓘ
 
     use Acme::EnclosedChar qw/enclose/;
 
-    Print enclose('Perl'); # Ⓟⓔⓡⓛ
+    print enclose('Perl'); # Ⓟⓔⓡⓛ
 
 
 =head1 DESCRIPTION
